# Automating "Hello World" with a subtask

Say you want to do the following task:

> Commit a script hello.py that prints out "Hello world".

First, follow the instructions at [`hello.md`](/zamm/resources/tutorials/hello.md) to perform the task of writing the script and executing it to make sure it works.

Then, *make sure to commit the script*.

```bash
$ git add .
$ git commit -m "Added hello world"
[master 0bb7541] Added hello world
 1 file changed, 1 insertion(+)
 create mode 100644 hello.py
```

That's all! **Don't take any more steps** because the task is now done!
